@@ -34,7 +34,7 @@ qlonglong Events::addEvent(const QString &sourceName, const QString &sourceDispl
             dt = QDateTime::fromString(timestamp, Qt::TextDate);
 
             if (!dt.isValid()) {
-                dt = QDateTime::fromString(timestamp.remove(',').split('+').first().trimmed(), "ddd d MMM yyyy hh:mm:ss");
+                dt = QDateTime::fromString(timestamp.section(' ', 0, -2).remove(','), "ddd d MMM yyyy hh:mm:ss");
 
                 if (!dt.isValid()) {
                     dt = QDateTime::currentDateTime();
@@ -117,19 +117,25 @@ void Events::getNextEvent() {
 }
 
 bool Events::removeEvent(qlonglong eventId) {
-    m_timer.start();
+    if (m_eventQueue.isEmpty()) {
+        m_timer.start();
+    }
 
     return m_database.removeEvent(eventId);
 }
 
 bool Events::removeEventsBySourceName(const QString &sourceName) {
-    m_timer.start();
+    if (m_eventQueue.isEmpty()) {
+        m_timer.start();
+    }
 
     return m_database.removeEventsBySourceName(sourceName);
 }
 
 bool Events::addRefreshAction(const QString &sourceName, const QString &action) {
-    m_timer.start();
+    if (m_eventQueue.isEmpty()) {
+        m_timer.start();
+    }
 
     if (m_database.addRefreshAction(sourceName, action)) {
         emit refreshActionsUpdated();
@@ -140,7 +146,9 @@ bool Events::addRefreshAction(const QString &sourceName, const QString &action)
 }
 
 bool Events::removeRefreshAction(const QString &sourceName) {
-    m_timer.start();
+    if (m_eventQueue.isEmpty()) {
+        m_timer.start();
+    }
 
     if (m_database.removeRefreshAction(sourceName)) {
         emit refreshActionsUpdated();
@@ -151,7 +159,9 @@ bool Events::removeRefreshAction(const QString &sourceName) {
 }
 
 QString Events::getRefreshAction(const QString &sourceName) {
-    m_timer.start();
+    if (m_eventQueue.isEmpty()) {
+        m_timer.start();
+    }
 
     return m_database.getRefreshAction(sourceName);
 }
