@@ -3,6 +3,7 @@
 #include "utils.h"
 #include <qmath.h>
 #include <QStaticText>
+#include <QRegExp>
 
 EventListDelegate::EventListDelegate(QObject *parent) :
     QStyledItemDelegate(parent)
@@ -60,7 +61,7 @@ void EventListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     textOption.setWrapMode(QTextOption::WordWrap);
     bodyText.setTextOption(textOption);
 
-    bodyRect.setHeight(qMin(option.fontMetrics.boundingRect(option.rect, Qt::TextWordWrap, body).height(), 50));
+    bodyRect.setHeight(qMin(option.fontMetrics.boundingRect(option.rect, Qt::TextWordWrap, body.replace(QRegExp("(<br />|<br/>)"), "\n")).height(), 50)); // HTML linebreaks result in wrong value for text height using QFontMetrics::boundingRect().
 
     painter->setClipRect(bodyRect);
     painter->drawStaticText(bodyRect.topLeft(), bodyText);
@@ -100,7 +101,7 @@ void EventListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
 
     QString footer = index.data(EventListModel::FooterRole).toString();
     QString date = Utils::dateFromMSecs(index.data(EventListModel::TimestampRole).toLongLong());
-    QStaticText footerText(QString ("%1 - %2").arg(footer).arg(date));
+    QStaticText footerText(footer.isEmpty() ? date : QString ("%1 - %2").arg(footer).arg(date));
     footerText.setTextWidth(footerRect.width());
     textOption.setWrapMode(QTextOption::NoWrap);
     footerText.setTextOption(textOption);
@@ -121,8 +122,8 @@ void EventListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
 }
 
 QSize EventListDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const {
-    int bodyHeight = qMin(option.fontMetrics.boundingRect(option.rect, Qt::TextWordWrap, index.data(EventListModel::BodyRole).toString()).height(), 50);
+    int bodyHeight = qMin(option.fontMetrics.boundingRect(option.rect, Qt::TextWordWrap, index.data(EventListModel::BodyRole).toString().replace(QRegExp("(<br />|<br/>)"), "\n")).height(), 50);
     QStringList imagePaths = index.data(EventListModel::ImagesRole).toStringList();
 
-    return imagePaths.isEmpty() ? QSize(option.rect.width(), bodyHeight + 50) : QSize(option.rect.width(), bodyHeight + 200);
+    return imagePaths.isEmpty() ? QSize(option.rect.width(), bodyHeight + 80) : QSize(option.rect.width(), bodyHeight + 200);
 }
